% Function to convolve FIR filter on data
%
% Runs standard FIR convolution with signal vector and filter vector
%
% Usage:
%   [filtered_signal] = FIR_filt(signal,filt,padded)  
%
% Input:
%       signal: signal to be filtered (1 by many vector)
%       filt: vector of FIR weights (1 by filter length)
%       padded: 1= yes (default), 0 = no -- should end points be padded with mean of
%           signal to avoid total loss of data for just under half the length
%           of the filter
%
% Version 0.9
%
% Written July, 2011, by John JB Allen jallen@u.arizona.edu
%
% See Also:  pop_optFIR, pop_optFIR_compare, pop_about_optFIR_compare, optFIR.m, optFIR_compare, optFIR_design, FIR_freq_rsps, IIR_freq_rsps

function [filtered_signal] = FIR_filt(signal,filt,padded)  

if nargin < 3 
    doc FIR_filt;
    return
end

if padded  % pad ends with mean value of the signal
    signal = [ones(1,(length(filt)-1)/2)*signal(1) signal ones(1,(length(filt)-1)/2)*signal(end)];
end

filtered_signal=conv(signal,filt,'same'); % conv calls built-in conv2 function which is super fast!

if padded  % trim padding so signal is original length
    filtered_signal = filtered_signal(1+(length(filt)-1)/2:end-(length(filt)-1)/2);
end
