%% Script to demo Woody Filter impact on average

%% Get data and channel info

% Set paths and launch EEGLab 
addpath(genpath('C:\Program Files\MATLAB\eeglab10_2_5_5a'));  % may vary depending on your location 
eeglab;

% import data file and get channel info
[ALLEEG EEG CURRENTSET ALLCOM] = eeglab;
EEG = pop_loadcnt('PIL999_VEOG.CNT' , 'dataformat', 'int16',  'keystroke', 'on');
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 0,'gui','off'); 
eeglab redraw;

% Rename CB sites that are mislabeled courtesy of Neuroscan
EEG.chanlocs(26).labels='FC5';
EEG.chanlocs(27).labels='FC6';
EEG.chanlocs(28).labels='CP5';
EEG.chanlocs(29).labels='CP6';
   
% Import Channel Location Information
EEG=pop_chanedit(EEG, 'lookup','C:\\Program Files\\MATLAB\\eeglab9_0_4_6s\\plugins\\dipfit2.2\\standard_BESA\\standard-10-5-cap385.elp');
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
EEG = eeg_checkset( EEG );
eeglab redraw

%% Epoch file
EEG = pop_epoch( EEG, {  '100'  '101'  }, [-0.25        1.25], 'newname', 'CNT file epochs', 'epochinfo', 'yes');
[ALLEEG EEG CURRENTSET] = pop_newset(ALLEEG, EEG, 1,'gui','off'); 
EEG = eeg_checkset( EEG );
EEG = pop_rmbase( EEG, [-250    0]);
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);
eeglab redraw

%% Perform ocular correction  (Must be installed in plugins directory under current version of EEGLab)
EEG = pop_gratton(EEG,1); % EEG = pop_gratton(EEG) -- this will pop up the GUI
[ALLEEG EEG CURRENTSET]=eeg_store(ALLEEG,EEG);
eeglab redraw;
[ALLEEG EEG] = eeg_store(ALLEEG, EEG, CURRENTSET);


%% Compare non-transformed to Woody-aligned average for rare (101) for Pz (15)
rare_code = 101;
Pz_channum = 15;
% Standard average
% matrix is channels by timepoints by epochs
% select only Pz in first dimension (channels)
% select only events for rare code in 3rd dimension (epoch) : [EEG.event.type] == rare_code
% squeeze the matrix to make it 2D instead of 3D with a singlton (channel)dimension (so it is now timepoints by epochs)
% now take mean across the second dimension of the squeezed matrix (epochs)
Pz_avg = mean(squeeze(EEG.data(Pz_channum,:,[EEG.event.type] == rare_code)),2); 

% Woody average
% use same approach to Pz channel, ans squeeze the matrix so we have a 2D matrix as input for woody
Pz_Avg_Woody = mean(woody(squeeze(EEG.data(Pz_channum,:,[EEG.event.type] == rare_code))),2);

% Compare!
figure
plot(EEG.times,Pz_avg)
hold on
plot(EEG.times,Pz_Avg_Woody,'-r')
set(gca,'YDir','reverse');  % Positive down

%% examine cross correlation functions of trials with the Pz average
Pz_epochs = squeeze(EEG.data(Pz_channum,:,[EEG.event.type] == rare_code));
maxlag_ms = 200;
n_epoch = 1;
r(n_epoch,:) = xcorr(Pz_epochs(:,n_epoch),Pz_avg,[round(maxlag_ms/(1000/EEG.srate))],'coeff');

figure;
for n_epoch = 1:size(Pz_epochs,2)
    r(n_epoch,:) = xcorr(Pz_epochs(:,n_epoch),Pz_avg,[round(maxlag_ms/(1000/EEG.srate))],'coeff');
    plot(-maxlag_ms:1000/EEG.srate:maxlag_ms,r(n_epoch,:));
    pause;
end

plot(-maxlag_ms:1000/EEG.srate:maxlag_ms,r)
pause
plot(-maxlag_ms:1000/EEG.srate:maxlag_ms,mean(r,1));

